==> huaweicloudsdkkafka-3.1.126-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/kafka_diagnosis_check_entity.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KafkaDiagnosisCheckEntity:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'reason': 'str',
        'success': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'reason': 'reason',
        'success': 'success'
    }

    def __init__(self, name=None, reason=None, success=None):
        """KafkaDiagnosisCheckEntity

        The model defined in huaweicloud sdk

        :param name: 预检查项名称
        :type name: str
        :param reason: 预检查失败原因
        :type reason: str
        :param success: 预检查是否正常
        :type success: bool
        """
        
        

        self._name = None
        self._reason = None
        self._success = None
        self.discriminator = None

        self.name = name
        self.reason = reason
        self.success = success

    @property
    def name(self):
        """Gets the name of this KafkaDiagnosisCheckEntity.

        预检查项名称

        :return: The name of this KafkaDiagnosisCheckEntity.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KafkaDiagnosisCheckEntity.

        预检查项名称

        :param name: The name of this KafkaDiagnosisCheckEntity.
        :type name: str
        """
        self._name = name

    @property
    def reason(self):
        """Gets the reason of this KafkaDiagnosisCheckEntity.

        预检查失败原因

        :return: The reason of this KafkaDiagnosisCheckEntity.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this KafkaDiagnosisCheckEntity.

        预检查失败原因

        :param reason: The reason of this KafkaDiagnosisCheckEntity.
        :type reason: str
        """
        self._reason = reason

    @property
    def success(self):
        """Gets the success of this KafkaDiagnosisCheckEntity.

        预检查是否正常

        :return: The success of this KafkaDiagnosisCheckEntity.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this KafkaDiagnosisCheckEntity.

        预检查是否正常

        :param success: The success of this KafkaDiagnosisCheckEntity.
        :type success: bool
        """
        self._success = success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KafkaDiagnosisCheckEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.151-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/kafka_diagnosis_check_entity.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class KafkaDiagnosisCheckEntity:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'reason': 'str',
        'success': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'reason': 'reason',
        'success': 'success'
    }

    def __init__(self, name=None, reason=None, success=None):
        r"""KafkaDiagnosisCheckEntity

        The model defined in huaweicloud sdk

        :param name: 预检查项名称
        :type name: str
        :param reason: 预检查失败原因
        :type reason: str
        :param success: 预检查是否正常
        :type success: bool
        """
        
        

        self._name = None
        self._reason = None
        self._success = None
        self.discriminator = None

        self.name = name
        self.reason = reason
        self.success = success

    @property
    def name(self):
        r"""Gets the name of this KafkaDiagnosisCheckEntity.

        预检查项名称

        :return: The name of this KafkaDiagnosisCheckEntity.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this KafkaDiagnosisCheckEntity.

        预检查项名称

        :param name: The name of this KafkaDiagnosisCheckEntity.
        :type name: str
        """
        self._name = name

    @property
    def reason(self):
        r"""Gets the reason of this KafkaDiagnosisCheckEntity.

        预检查失败原因

        :return: The reason of this KafkaDiagnosisCheckEntity.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        r"""Sets the reason of this KafkaDiagnosisCheckEntity.

        预检查失败原因

        :param reason: The reason of this KafkaDiagnosisCheckEntity.
        :type reason: str
        """
        self._reason = reason

    @property
    def success(self):
        r"""Gets the success of this KafkaDiagnosisCheckEntity.

        预检查是否正常

        :return: The success of this KafkaDiagnosisCheckEntity.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        r"""Sets the success of this KafkaDiagnosisCheckEntity.

        预检查是否正常

        :param success: The success of this KafkaDiagnosisCheckEntity.
        :type success: bool
        """
        self._success = success

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KafkaDiagnosisCheckEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
